@@ -1,6 +1,6 @@
 /*
     orzcharlist
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,14 +50,12 @@ struct _OrzCharlist
   GtkWidget *cancel_button; /* ja:取消 */
 
   /*< private >*/
-  GtkWidget *new_button;    /* ja:新規 */
+  GtkWidget *add_button;    /* ja:追加 */
   GtkWidget *remove_button; /* ja:削除 */
   GtkWidget *up_button;     /* ja:上へ */
   GtkWidget *down_button;   /* ja:下へ */
   GtkWidget *charset;       /* ja:文字符号化方式 */
   GtkWidget *tview;         /* ja:リスト */
-  GtkListStore *store;      /* ja:リスト */
-  GtkTreeSelection *select; /* ja:リスト */
 };
 
 struct _OrzCharlistClass
