@@ -134,7 +134,11 @@ command_save (GtkWidget *widget,
       gchar *path;
       gint leng;
 
+#if GLIB_CHECK_VERSION(2,6,0)
+      path = g_filename_display_name (root);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       path = g_filename_to_utf8 (root, -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       leng = g_strlen (path);
       for (i = mm_list_length (MM_LIST (mmaid->list)) - 1; i >= 0; i--)
         {
@@ -159,7 +163,11 @@ command_save (GtkWidget *widget,
           gchar *utf8str;
           GtkWidget *dialog;
 
+#if GLIB_CHECK_VERSION(2,6,0)
+          utf8str = g_filename_display_name (file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
           utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
@@ -302,7 +310,7 @@ command_saveas (GtkWidget *widget,
   *path = '\0';
 #ifdef G_OS_WIN32
   if (g_strlen (root) > 2
-                && root[0] == G_DIR_SEPARATOR && root[1] == G_DIR_SEPARATOR)
+            && G_IS_DIR_SEPARATOR (root[0]) && G_IS_DIR_SEPARATOR (root[1]))
     {
       path = g_strdup (G_DIR_SEPARATOR_S G_DIR_SEPARATOR_S);
       ary = g_strsplit (root + 2, G_DIR_SEPARATOR_S, 0);
@@ -519,7 +527,11 @@ command_saveas (GtkWidget *widget,
         {
           gchar *utf8str;
 
+#if GLIB_CHECK_VERSION(2,6,0)
+          utf8str = g_filename_display_name (file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
           utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
@@ -1015,8 +1027,8 @@ command_search_recursive (const gchar *path,
                       {
                         mm_list_show_add
                                 (MM_LIST (MM_DIALOG (dialog)->list), n1);
-                        if (g_strlen (file) > 4 && !g_strcasecmp (".mp3",
-                                                file + g_strlen (file) - 4))
+                        if (g_strlen (file) > 4 && g_ascii_strcasecmp (".mp3",
+                                            file + g_strlen (file) - 4) == 0)
                           mm_list_set_active_add
                                 (MM_LIST (MM_DIALOG (dialog)->list), n1, TRUE);
                       }
@@ -1108,7 +1120,7 @@ command_search (GtkWidget *widget,
         {
           gchar *tmp;
 
-          if (path[g_strlen (path) - 1] != G_DIR_SEPARATOR)
+          if (!G_IS_DIR_SEPARATOR (path[g_strlen (path) - 1]))
             {
               tmp = g_strconcat (path, G_DIR_SEPARATOR_S, NULL);
               g_free (path);
@@ -1138,7 +1150,7 @@ command_search (GtkWidget *widget,
       g_free (tmp);
       return;
     }
-  if (tmp[g_strlen (tmp) - 1] == G_DIR_SEPARATOR)
+  if (G_IS_DIR_SEPARATOR (tmp[g_strlen (tmp) - 1]))
     tmp[g_strlen (tmp) - 1] = '\0';
   path = g_filename_from_utf8 (tmp, -1, NULL, NULL, NULL);
   g_free (tmp);
