@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1026,6 +1026,8 @@ file_save_db (const gchar *file,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             text);
           g_free (text);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
           dialog = NULL;
@@ -1052,6 +1054,8 @@ file_save_db (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not open file"));
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       userbreak = FALSE;
@@ -1062,6 +1066,8 @@ file_save_db (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not write"));
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       userbreak = FALSE;
@@ -1161,6 +1167,8 @@ file_save_list (const gchar *file,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Conversion from character encoding"
                               " 'UTF-8' to '%s' is not supported"), charset);
+                  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
                   gtk_dialog_run (GTK_DIALOG (dialog));
                   gtk_widget_destroy (dialog);
                   dialog = NULL;
@@ -1193,6 +1201,8 @@ file_save_list (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not write"));
+                  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
                   gtk_dialog_run (GTK_DIALOG (dialog));
                   gtk_widget_destroy (dialog);
                   dialog = NULL;
@@ -1215,6 +1225,8 @@ file_save_list (const gchar *file,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Can not open file"));
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       userbreak = FALSE;
