@@ -93,7 +93,6 @@ gchar *def_genre_list[256] = {
 ******************************************************************************/
 typedef struct _GenreDialog
 {
-  GtkListStore *store;
   GtkWidget *dialog, *tview, *button0, *button1, *button2, *button3;
 } GenreDialog;
 
@@ -138,14 +137,17 @@ genre_dialog_edited (GtkCellRendererText *cell,
                      GenreDialog         *gnrdlg)
 {
   gint column;
+  GtkListStore *store;
   GtkTreeIter iter;
   GtkTreePath *path;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (gnrdlg->tview)));
   column = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (cell), "user_data"));
   path = gtk_tree_path_new_from_string (path_string);
-  gtk_tree_model_get_iter (GTK_TREE_MODEL (gnrdlg->store), &iter, path);
+  gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path);
   gtk_tree_path_free (path);
-  gtk_list_store_set (gnrdlg->store, &iter,
+  gtk_list_store_set (store, &iter,
                 column, text && text[0] != '\0' ? g_strdup (text) : NULL, -1);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (gnrdlg->dialog),
                                                         GTK_RESPONSE_OK, TRUE);
@@ -161,9 +163,12 @@ genre_dialog_clicked_new (GtkWidget   *widget,
   gint i, c, count;
   GList *glist;
   GtkCellRenderer *renderer;
+  GtkListStore *store;
   GtkTreePath *path;
   GtkTreeViewColumn *column;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (gnrdlg->tview)));
   gtk_tree_view_get_cursor (GTK_TREE_VIEW (gnrdlg->tview), &path, &column);
   c = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (column), "user_data"));
   glist = gtk_tree_view_get_columns (GTK_TREE_VIEW (gnrdlg->tview));
@@ -174,21 +179,19 @@ genre_dialog_clicked_new (GtkWidget   *widget,
       gint j;
       GtkTreeIter iter;
 
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (gnrdlg->store), &iter,
-                                                                    NULL, i);
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
       for (j = count; j > c; j--)
         {
           gchar *str;
 
-          gtk_tree_model_get (GTK_TREE_MODEL (gnrdlg->store), &iter,
-                                                            j - 1, &str, -1);
-          gtk_list_store_set (gnrdlg->store, &iter, j, str, -1);
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, j - 1, &str, -1);
+          gtk_list_store_set (store, &iter, j, str, -1);
           g_free (str);
         }
     }
   renderer = gtk_cell_renderer_text_new ();
   g_signal_connect (renderer, "edited",
-                            G_CALLBACK (genre_dialog_edited), gnrdlg->store);
+                                    G_CALLBACK (genre_dialog_edited), gnrdlg);
   g_object_set_data (G_OBJECT (renderer), "user_data",
                                                     GINT_TO_POINTER (count));
   title = g_strdup_printf ("%d", count);
@@ -211,9 +214,12 @@ genre_dialog_clicked_delete (GtkWidget   *widget,
 {
   gint i, c, count;
   GList *glist;
+  GtkListStore *store;
   GtkTreePath *path;
   GtkTreeViewColumn *column;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (gnrdlg->tview)));
   gtk_tree_view_get_cursor (GTK_TREE_VIEW (gnrdlg->tview), &path, &column);
   c = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (column), "user_data"));
   glist = gtk_tree_view_get_columns (GTK_TREE_VIEW (gnrdlg->tview));
@@ -224,15 +230,13 @@ genre_dialog_clicked_delete (GtkWidget   *widget,
       gint j;
       GtkTreeIter iter;
 
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (gnrdlg->store), &iter,
-                                                                    NULL, i);
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
       for (j = c; j < count; j++)
         {
           gchar *str;
 
-          gtk_tree_model_get (GTK_TREE_MODEL (gnrdlg->store), &iter,
-                                                            j + 1, &str, -1);
-          gtk_list_store_set (gnrdlg->store, &iter, j, str, -1);
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, j + 1, &str, -1);
+          gtk_list_store_set (store, &iter, j, str, -1);
           g_free (str);
         }
     }
@@ -250,9 +254,12 @@ genre_dialog_clicked_up (GtkWidget   *widget,
                          GenreDialog *gnrdlg)
 {
   gint i, c;
+  GtkListStore *store;
   GtkTreePath *path;
   GtkTreeViewColumn *column;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (gnrdlg->tview)));
   gtk_tree_view_get_cursor (GTK_TREE_VIEW (gnrdlg->tview), &path, &column);
   c = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (column), "user_data"));
   for (i = 0; i < 256; i++)
@@ -260,11 +267,10 @@ genre_dialog_clicked_up (GtkWidget   *widget,
       gchar *str0, *str1;
       GtkTreeIter iter;
 
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (gnrdlg->store), &iter,
-                                                                    NULL, i);
-      gtk_tree_model_get (GTK_TREE_MODEL (gnrdlg->store), &iter,
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                         c - 1, &str0, c, &str1, -1);
-      gtk_list_store_set (gnrdlg->store, &iter, c - 1,  str1, c,  str0, -1);
+      gtk_list_store_set (store, &iter, c - 1,  str1, c,  str0, -1);
       g_free (str0);
       g_free (str1);
     }
@@ -282,9 +288,12 @@ genre_dialog_clicked_down (GtkWidget   *widget,
                            GenreDialog *gnrdlg)
 {
   gint i, c;
+  GtkListStore *store;
   GtkTreePath *path;
   GtkTreeViewColumn *column;
 
+  store = GTK_LIST_STORE (gtk_tree_view_get_model
+                                            (GTK_TREE_VIEW (gnrdlg->tview)));
   gtk_tree_view_get_cursor (GTK_TREE_VIEW (gnrdlg->tview), &path, &column);
   c = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (column), "user_data"));
   for (i = 0; i < 256; i++)
@@ -292,11 +301,10 @@ genre_dialog_clicked_down (GtkWidget   *widget,
       gchar *str0, *str1;
       GtkTreeIter iter;
 
-      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (gnrdlg->store), &iter,
-                                                                    NULL, i);
-      gtk_tree_model_get (GTK_TREE_MODEL (gnrdlg->store), &iter,
+      gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                         c , &str0, c + 1, &str1, -1);
-      gtk_list_store_set (gnrdlg->store, &iter, c ,  str1, c + 1,  str0, -1);
+      gtk_list_store_set (store, &iter, c ,  str1, c + 1,  str0, -1);
       g_free (str0);
       g_free (str1);
     }
@@ -322,6 +330,7 @@ genre_dialog (void)
 {
   gint i, j;
   GType types[258];
+  GtkListStore *store;
   GtkTreeViewColumn *column;
   GtkWidget *scroll, *hbox, *vbox;
   GenreDialog gnrdlg;
@@ -351,17 +360,13 @@ genre_dialog (void)
                             G_CALLBACK (genre_dialog_clicked_up), &gnrdlg);
   g_signal_connect (G_OBJECT (gnrdlg.button3), "clicked",
                             G_CALLBACK (genre_dialog_clicked_down), &gnrdlg);
-  GTK_WIDGET_SET_FLAGS (gnrdlg.button0, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (gnrdlg.button1, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (gnrdlg.button2, GTK_CAN_DEFAULT);
-  GTK_WIDGET_SET_FLAGS (gnrdlg.button3, GTK_CAN_DEFAULT);
   /* ja:リストボックス */
   for (i = 0; i < 256; i++)
     types[i] = G_TYPE_STRING;
   types[256] = G_TYPE_INT;
   types[257] = G_TYPE_BOOLEAN;
-  gnrdlg.store = gtk_list_store_newv (258, types);
-  gnrdlg.tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (gnrdlg.store));
+  store = gtk_list_store_newv (258, types);
+  gnrdlg.tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   g_signal_connect (G_OBJECT (gnrdlg.tview), "cursor-changed",
                             G_CALLBACK (genre_dialog_cursor_changed), &gnrdlg);
   /* ja:コラム */
@@ -391,10 +396,10 @@ genre_dialog (void)
     {
       GtkTreeIter iter;
 
-      gtk_list_store_append (gnrdlg.store, &iter);
-      gtk_list_store_set (gnrdlg.store, &iter, 256, i, 257, TRUE, -1);
+      gtk_list_store_append (store, &iter);
+      gtk_list_store_set (store, &iter, 256, i, 257, TRUE, -1);
       for (j = 0; j < genres; j++)
-        gtk_list_store_set (gnrdlg.store, &iter, j, genre[j][i], -1);
+        gtk_list_store_set (store, &iter, j, genre[j][i], -1);
     }
   /* ja:スクロールウインドウ */
   scroll = gtk_scrolled_window_new (NULL, NULL);
@@ -438,10 +443,10 @@ genre_dialog (void)
         {
           GtkTreeIter iter;
 
-          gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (gnrdlg.store), &iter,
+          gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter,
                                                                     NULL, i);
           for (j = 0; j < genres; j++)
-            gtk_tree_model_get (GTK_TREE_MODEL (gnrdlg.store), &iter,
+            gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                                         j, &genre[j][i], -1);
         }
       for (i = 0; i < genres; i++)
