@@ -110,7 +110,7 @@ MiscCreateMenuEntry menu_entries[] = {
 {"/option/process",     N_("_Process"),            NULL,              process16_xpm,    MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_process, NULL, NULL},
 {"/window",             N_("_Window"),             NULL,              NULL,             MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
 {"/window/",            NULL,                      NULL,              NULL,             MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
-{"/help",               N_("_Help"),               NULL,              NULL,             MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
+{"/help",               GTK_STOCK_HELP,            NULL,              NULL,             MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_NOIMAGE,  NULL,            NULL, NULL},
 {"/help/",              NULL,                      NULL,              NULL,             MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
 #if GTK_CHECK_VERSION(2,6,0)
 {"/help/about",         GTK_STOCK_ABOUT,           NULL,              NULL,             MISC_CREATE_MENU_STOCK,                             command_version, NULL, NULL},
@@ -216,16 +216,16 @@ main (int   argc,
       locale = g_win32_get_package_installation_subdirectory
                             (NULL, argv[0], "lib" G_DIR_SEPARATOR_S "locale");
     }
-# endif /* G_OS_WIN32 */
-# if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
-#  if GLIB_CHECK_VERSION(2,8,0)
+#  if GLIB_CHECK_VERSION(2,6,0)
+#   if GLIB_CHECK_VERSION(2,8,0)
   temp = g_win32_locale_filename_from_utf8 (locale);
-#  else /* not GLIB_CHECK_VERSION(2,8,0) */
+#   else /* not GLIB_CHECK_VERSION(2,8,0) */
   temp = g_locale_from_utf8 (locale, -1, NULL, NULL, NULL);
-#  endif /* not GLIB_CHECK_VERSION(2,8,0) */
+#   endif /* not GLIB_CHECK_VERSION(2,8,0) */
   g_free (locale);
   locale = temp;
-# endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
+#  endif /* GLIB_CHECK_VERSION(2,6,0) */
+# endif /* G_OS_WIN32 */
   bindtextdomain (PACKAGE, locale);
   g_free (locale);
 #endif /* not LOCALEDIR */
