@@ -45,7 +45,7 @@ root_dialog_clicked (GtkWidget  *widget,
   GtkWidget *dialog;
 
   root = g_strdup (gtk_entry_get_text (GTK_ENTRY (rtdlg->entry)));
-  if (root[0] == '\0' || root[g_strlen (root) - 1] != G_DIR_SEPARATOR)
+  if (root[0] == '\0' || !G_IS_DIR_SEPARATOR (root[g_strlen (root) - 1]))
 #if GTK_CHECK_VERSION(2,6,0)
     root = gtk_combo_box_get_active_text (GTK_COMBO_BOX (rtdlg->combo));
 #elif GTK_CHECK_VERSION(2,4,0)
@@ -63,7 +63,7 @@ root_dialog_clicked (GtkWidget  *widget,
                                 (GTK_ENTRY (GTK_COMBO (rtdlg->combo)->entry)));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
   path = root && root[0] != '\0'
-                                && root[g_strlen (root) - 1] == G_DIR_SEPARATOR
+                            && G_IS_DIR_SEPARATOR (root[g_strlen (root) - 1])
                     ? g_filename_from_utf8 (root, -1, NULL, NULL, NULL) : NULL;
   g_free (root);
 #if GTK_CHECK_VERSION(2,4,0)
@@ -203,7 +203,6 @@ root_dialog (MmaidWindow *mmaid)
   button = gtk_button_new_with_mnemonic (_("_Browse..."));
   g_signal_connect (G_OBJECT (button), "clicked",
                                     G_CALLBACK (root_dialog_clicked), &rtdlg);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   /* ja:コンボボックス */
   rtdlg.unselect_all = TRUE;
   count = mm_list_length (MM_LIST (mmaid->list));
@@ -222,8 +221,8 @@ root_dialog (MmaidWindow *mmaid)
 
         id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
 #ifdef G_OS_WIN32
-        if (g_strlen (id3tag->file) > 2 && id3tag->file[0] == G_DIR_SEPARATOR
-                                        && id3tag->file[1] == G_DIR_SEPARATOR)
+        if (g_strlen (id3tag->file) > 2 && G_IS_DIR_SEPARATOR (id3tag->file[0])
+                                    && G_IS_DIR_SEPARATOR (id3tag->file[1]))
           {
             path = g_strdup (G_DIR_SEPARATOR_S G_DIR_SEPARATOR_S);
             dir = g_strsplit (id3tag->file + 2, G_DIR_SEPARATOR_S, 0);
@@ -244,9 +243,10 @@ root_dialog (MmaidWindow *mmaid)
             g_free (path);
             path = tmp;
 #ifdef G_OS_WIN32
-            if (!g_list_find_custom (glist, path, (GCompareFunc)g_strcasecmp))
+            if (!g_list_find_custom (glist, path,
+                                            (GCompareFunc)g_ascii_strcasecmp))
               glist = g_list_insert_sorted (glist, g_strdup (path),
-                                                (GCompareFunc)g_strcasecmp);
+                                            (GCompareFunc)g_ascii_strcasecmp);
 #else /* not G_OS_WIN32 */
             if (!g_list_find_custom (glist, path, (GCompareFunc)strcmp))
               glist = g_list_insert_sorted (glist, g_strdup (path),
